﻿
using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;

using MindFusion.Spreadsheet;
using System.Globalization;


namespace SpreadsheetConditionalFormats
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();

			// Initialize the worksheet data
			var names = new CultureInfo("en-US").DateTimeFormat.AbbreviatedMonthNames;
			var avgHigh = new int[] { 4, 7, 12, 17, 21, 25, 28, 28, 23, 18, 10, 4 };
			var avgLow = new int[] { -5, -4, 0, 5, 9, 13, 14, 14, 10, 6, 0, -4 };
			var recordHigh = new int[] { 16, 17, 24, 28, 29, 32, 37, 34, 34, 30, 24, 17 };
			var recordLow = new int[] { -21, -19, -15, -5, -1, 4, 7, 8, -2, -2, -7, -16 };
			var worksheet = workbook1.Worksheets[0];

			worksheet.BeginInit();
			for (int i = 0; i < 12; i++)
			{
				worksheet.Cells[i + 1, 0].Data = names[i];
				worksheet.Cells[i + 1, 1].Data = avgHigh[i];
				worksheet.Cells[i + 1, 2].Data = avgLow[i];
				worksheet.Cells[i + 1, 3].Data = recordHigh[i];
				worksheet.Cells[i + 1, 4].Data = recordLow[i];
			}
			worksheet.Cells["A2"].Data = "Avg High";
			worksheet.Cells["A3"].Data = "Avg Low";
			worksheet.Cells["A4"].Data = "Record High";
			worksheet.Cells["A5"].Data = "Record Low";
			worksheet.Columns[1, 12].Width = "24pt";

			var dataStyle = worksheet.CellRanges["B2:M5"].Style;
			// Color progresion: 89,138,197 => 248,105,107
			Color fromColor = Color.FromArgb(89, 138, 197);
			Color toColor = Color.FromArgb(248, 105, 107);
			Color midColor = Color.FromArgb(251, 233, 135);
			int step = 5;
			int from = -25;
			int to = 40;
			int mid = from + (to - from) / 2;
			for (int i = -25; i < 40; i += step)
			{
				var conditionalFormat = dataStyle.ConditionalFormats.Add();
				conditionalFormat.Type = ConditionalFormatType.CellValue;
				conditionalFormat.First = i.ToString();
				conditionalFormat.Second = (i + step).ToString();
				int start;
				int end;
				Color startColor;
				Color endColor;
				if (i > mid)
				{
					startColor = midColor;
					endColor = toColor;
					start = mid;
					end = to;
				}
				else
				{
					startColor = fromColor;
					endColor = midColor;
					start = from;
					end = mid;
				}
				conditionalFormat.Style.Background = new MindFusion.Drawing.SolidBrush(Color.FromArgb(
					startColor.R + (endColor.R - startColor.R) * (i - start) / (end - start),
					startColor.G + (endColor.G - startColor.G) * (i - start) / (end - start),
					startColor.B + (endColor.B - startColor.B) * (i - start) / (end - start)));
			}

			var headerStyle = worksheet.CellRanges["B1:M1"].Style;
			headerStyle.FontBold = true;
			headerStyle.HorizontalAlignment = MindFusion.Spreadsheet.HorizontalAlignment.Center;
			worksheet.EndInit();
			workbookView1.ResizeColumnsToFit(0, 0);
		}
	}
}
